<?php
/**
 * Moony - the tiny web application framework
 *
 * @package   Moony
 * @author    YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @link      http://moony.sourceforge.jp/
 * @copyright 2005-2006 YAMAOKA Hiroyuki
 * @license   http://opensource.org/licenses/bsd-license.php The BSD License
 */

/**
 * テンプレートエンジンとしてSmartyを利用するためのクラスです。
 *
 * @package Moony
 * @author YAMAOKA Hiroyuki <yamaoka@catwalker.jp>
 * @access public
 */
class Moony_Smarty extends Smarty
{
    /**
     * コンストラクタです。
     *
     * @access public
     * @param array $properties プロパティに設定する値の連想配列
     */
    function Moony_Smarty($properties = null)
    {
        parent::Smarty();

        // properties
        if (is_array($properties)) {
            $prop_keys = array_keys(get_object_vars($this));
            foreach ($properties as $name => $value) {
                if (in_array($name, $prop_keys)) {
                    // replace
                    $this->{$name} = $value;
                }
            }
        }

        // plugins
        $this->register_function(
            'moony_errors', array($this, 'moonyErrors'));
        $this->register_block(
            'moony_has_error', array($this, 'moonyHasError'));
    }

    /**
     * 全ての検証エラーメッセージを表示するヘルパー関数です。
     * エラーメッセージが設定されていない場合、何も処理しません。
     * （例: {moony_errors}）
     *
     * @access public
     * @param array $params パラメータの連想配列
     * @param object $smarty Smartyのインスタンス
     */
    function moonyErrors($params, &$smarty)
    {
        $validator =& Moony_Registry::get('_moony_validator');
        if (is_null($validator)) {
            return;
        }

        $header = isset($params['header']) ? $params['header'] : '<ul>';
        $footer = isset($params['footer']) ? $params['footer'] : '</ul>';
        $prefix = isset($params['prefix']) ? $params['prefix'] : '<li>';
        $postfix = isset($params['postfix']) ? $params['postfix'] : '</li>';

        $error_messages = $validator->getErrorMessages();
        if (is_array($error_messages) && count($error_messages) > 0) {
            echo $header;
            foreach ($error_messages as $error_message) {
                echo $prefix, $error_message, $postfix;
            }
            echo $footer;
        }
    }

    /**
     * 検証エラーの有無を判断するブロックです。
     *
     * @access public
     * @param array $params パラメータ配列
     * @param string $content ブロックの内容
     * @param object $smarty Smartyのインスタンス
     */
    function moonyHasError($params, $content, &$smarty)
    {
        $validator =& Moony_Registry::get('_moony_validator');
        if (!is_null($validator)) {
            if ($validator->hasError()) {
                echo $content;
            }
        }
    }
}
?>
